==> bugslife_1_3_03.zip: bugslife_1_3_03/WEB-INF/src/jp/gr/java_conf/bugslife/action/BugDetail4Action.java <==
//===========================================================================
// package
//===========================================================================
package jp.gr.java_conf.bugslife.action;

//===========================================================================
// import
//===========================================================================
import java.io.IOException;
import java.util.Locale;
import javax.servlet.*;
import javax.servlet.http.*;
import org.apache.commons.logging.*;
import org.apache.struts.action.*;
import org.apache.struts.util.*;
import org.apache.commons.beanutils.*;

import java.util.*;
import jp.gr.java_conf.bugslife.selections.*;
import jp.gr.java_conf.bugslife.user.*;
import jp.gr.java_conf.bugslife.bug.*;
import jp.gr.java_conf.bugslife.db.*;
import jp.gr.java_conf.bugslife.form.*;
import jp.gr.java_conf.bugslife.system.*;
import jp.gr.java_conf.bugslife.util.Converter;
import jp.gr.java_conf.bugslife.util.Assert;
import jp.gr.java_conf.bugslife.util.Varidater;
/**
 *<PRE>
 * 
 * BugDetail4ActionNX
 *
 *</PRE>
 * @version	0.0
 * @author	k 
 */
public final class BugDetail4Action extends BaseAction 
{
//===========================================================================
// attributes
//===========================================================================
	/**
	 * Form
	 */
	BugDetail4Form m_form;
	/**
	 * session
	 */
	HttpSession m_session;
	/**
	 * Bug
	 */
	Bug m_bug = null;
	/**
	 * Bug
	 */
	UserInfo m_logonUser;
	/**
	 * Log
	 */
	private Log log = LogFactory.getLog(this.getClass().getName());
	/**
	 * to
	 */
	private int m_toUno;
//===========================================================================
// methods
//===========================================================================
	/**
	 * exevute
	 *
	 * @param mapping The ActionMapping used to select this instance
	 * @param actionForm The optional ActionForm bean for this request (if any)
	 * @param request The HTTP request we are processing
	 * @param response The HTTP response we are creating
	 *
	 * @exception Exception if business logic throws an exception
	 */
	public synchronized ActionForward doAction(ActionMapping mapping,
				 ActionForm form,
				 HttpServletRequest request,
				 HttpServletResponse response)
				throws Exception {
		
		ActionForward forward = null;
		/*
		 * 
		 */
		m_form = (BugDetail4Form)form;	//form̎擾
		m_session = getSession(request);//sessio̎擾
		m_logonUser = (UserInfo)getAttribute(m_session,"UserInfo");	//OC[U̎擾
		m_bug = (Bug)m_session.getAttribute("bug");	//oO̎擾
		
		String action = m_form.getAction();
		//debug
		log.debug(	"action =" + action + 
					" submiteType = " + m_form.getSubmitType() +
					" bno = " + m_form.getBno() +
					" bno(s) = " + (m_bug == null ? "null" : ""+m_bug.getBno()));
		
		//\̏ꍇ
		if (action.equals("show")){
			
			//=========================
			//bugCX^X̎擾
			//=========================
			//ZbVɖbnoႤꍇ
			if ((m_bug == null) || (m_bug.getBno() != m_form.getBno())) {
				//oOCX^X̎擾
				m_bug = new Bug(m_form.getBno());
				//oOCX^X̃Zbg
				m_session.setAttribute("bug", m_bug);
			
			//̃oOXVĂꍇ
			} else {
				if (m_bug.isChanged()){
					//debug
					log.debug("is changed!");
					
					//oOCX^X̎擾
					m_bug = new Bug(m_form.getBno());
					//oOCX^X̃Zbg
					m_session.setAttribute("bug", m_bug);
				}
			}
			
			//͏Zbg
			PropertyUtils.copyProperties(m_form, m_bug);
			
			//show֑J
			forward = mapping.findForward("show");
			
		//XV̏ꍇ
		} else {
			
			//=========================
			//bugCX^X̎擾
			//=========================
			if ((m_bug == null) || (m_bug.getBno() != m_form.getBno())) {
				//xI
				log.warn("unmatch bno ");
				//oOCX^X̎擾
				m_bug = new Bug(m_form.getBno());
				//oOCX^X̍ăZbg
				m_session.setAttribute("bug", m_bug);
			}
			
			//`FbN
			ActionErrors errors = m_form.validate(mapping, request);
			if (!errors.empty()) {
				 saveErrors(request, errors);
				return (new ActionForward(mapping.getInput()));
			}
			
			try {
			
				//擾Jn
				m_bug.startActivity();
				
				//͏Zbg
				PropertyUtils.copyProperties(m_bug, m_form);
				//͏^CṽZbg
				m_bug.setInputType(Bug.ITYPE_DETAIL4);	
				
				//Xe[^X̍XV
				updateStatus();
				//r`FbN˂Ă܂XVB
				m_bug.update(m_logonUser.getUno());		//XV
				
				//͓e̒ǉ
				m_bug.addText(m_form.getAddText(), m_logonUser);
				//̎擾I
				m_bug.endActivity();
				
				//Ă
				Activitys act = m_bug.getActivitys();
				//[MsvłȂ
				if (! m_form.getDontSendMail()) {
					//[M
					act.sendMail(m_logonUser, request);
				}
				//̏o
				act.addActivity(m_logonUser);
				
				//OUPDATEĂ邽߂ɍXVeςȂꍇA
				//setPersistDateł̃j[NArG[ƂȂ
				//̂JDBChCoςĎ邪AƂ肠r`FbN
				//͂čXVB
				
				m_bug.update(m_logonUser.getUno(), false);		//rȂ̍XV
				
				//success֑J
				forward = mapping.findForward("success");
				
			//rO
			} catch (ExclusionException ee) {
				//debug
				log.debug("ExclusionException", ee);
				
				Varidater.addErrors("exp.exclusion", "bug", errors);
				saveErrors(request, errors);
				return (new ActionForward(mapping.getInput()));
				
			}
		}
		// Forward control to the specified success URI
		return forward;
	}
	/**
	 * Xe[^X̕ύX
	 */
	private void updateStatus() {
		
		String submitType = m_form.getSubmitType();
		//log
		log.debug("submiteType = " + submitType);
		log.debug("updater = " + m_form.getRequestUpdater() +
				  " analyst = " + m_form.getRequestAnalyst()
		);
		
		//s҂ɊmF˗
		if (submitType.equals("resolvedIssuer")) {
			m_bug.setUpdater(m_logonUser.getUno());	//CҐݒ
			m_bug.setBugUpdateDate(new Date());		//Cݒ
			m_bug.setComfirmer(m_bug.getIssuer());
			
			m_bug.setStatus(Bug.STS_RESOLVED);
			
		//C
		} else if (submitType.equals("repaired")) {
			int updater = Integer.parseInt(m_form.getRequestUpdater());
			m_bug.setUpdater(updater);				//CҐݒ
			m_bug.setBugUpdateDate(new Date());		//Cݒ
			
			m_bug.setStatus(Bug.STS_REPAIRED);
			
		//͒
		} else if (submitType.equals("investigation")) {
			int analyst = Integer.parseInt(m_form.getRequestAnalyst());
			m_bug.setUpdater(m_logonUser.getUno());	//CҐݒ
			m_bug.setBugUpdateDate(new Date());		//Cݒ
			m_bug.setAnalyst(analyst);				//͎Ґݒ
			
			m_bug.setStatus(Bug.STS_INVESTIGATION);
			
		//̂܂
		} else if (submitType.equals("same")) {
			//ȂɂȂ
			
		//Xe[^X󋵕ύX
		} else if (submitType.equals("statusWhitebord")) {
			
			m_bug.setStatusWhitebord(m_form.getRequestStatusWhitebord());
			
		} else {
			//ɂ͗Ȃ͂
			Assert.check(false, "invalid submitType type = " + submitType);
			
		}
	}
}

==> bugslife_1_3_04.zip: bugslife_1_3_04/WEB-INF/src/jp/gr/java_conf/bugslife/action/BugDetail4Action.java <==
//===========================================================================
// package
//===========================================================================
package jp.gr.java_conf.bugslife.action;

//===========================================================================
// import
//===========================================================================
import java.io.IOException;
import java.util.Locale;
import javax.servlet.*;
import javax.servlet.http.*;
import org.apache.commons.logging.*;
import org.apache.struts.action.*;
import org.apache.struts.util.*;
import org.apache.commons.beanutils.*;

import java.util.*;
import jp.gr.java_conf.bugslife.selections.*;
import jp.gr.java_conf.bugslife.user.*;
import jp.gr.java_conf.bugslife.bug.*;
import jp.gr.java_conf.bugslife.db.*;
import jp.gr.java_conf.bugslife.form.*;
import jp.gr.java_conf.bugslife.system.*;
import jp.gr.java_conf.bugslife.util.Converter;
import jp.gr.java_conf.bugslife.util.Assert;
import jp.gr.java_conf.bugslife.util.Varidater;
/**
 *<PRE>
 * 
 * BugDetail4ActionNX
 *
 *</PRE>
 * @version	0.0
 * @author	k 
 */
public final class BugDetail4Action extends BaseAction 
{
//===========================================================================
// attributes
//===========================================================================
	/**
	 * Form
	 */
	BugDetail4Form m_form;
	/**
	 * session
	 */
	HttpSession m_session;
	/**
	 * Bug
	 */
	Bug m_bug = null;
	/**
	 * Bug
	 */
	UserInfo m_logonUser;
	/**
	 * Log
	 */
	private Log log = LogFactory.getLog(this.getClass().getName());
	/**
	 * to
	 */
	private int m_toUno;
//===========================================================================
// methods
//===========================================================================
	/**
	 * exevute
	 *
	 * @param mapping The ActionMapping used to select this instance
	 * @param actionForm The optional ActionForm bean for this request (if any)
	 * @param request The HTTP request we are processing
	 * @param response The HTTP response we are creating
	 *
	 * @exception Exception if business logic throws an exception
	 */
	public synchronized ActionForward doAction(ActionMapping mapping,
				 ActionForm form,
				 HttpServletRequest request,
				 HttpServletResponse response)
				throws Exception {
		
		ActionForward forward = null;
		/*
		 * 
		 */
		m_form = (BugDetail4Form)form;	//form̎擾
		m_session = getSession(request);//sessio̎擾
		m_logonUser = (UserInfo)getAttribute(m_session,"UserInfo");	//OC[U̎擾
		m_bug = (Bug)m_session.getAttribute("bug");	//oO̎擾
		
		String action = m_form.getAction();
		//debug
		log.debug(	"action =" + action + 
					" submiteType = " + m_form.getSubmitType() +
					" bno = " + m_form.getBno() +
					" bno(s) = " + (m_bug == null ? "null" : ""+m_bug.getBno()));
		
		//\̏ꍇ
		if (action.equals("show")){
			
			//=========================
			//bugCX^X̎擾
			//=========================
			//ZbVɖbnoႤꍇ
			if ((m_bug == null) || (m_bug.getBno() != m_form.getBno())) {
				//oOCX^X̎擾
				m_bug = new Bug(m_form.getBno());
				//oOCX^X̃Zbg
				m_session.setAttribute("bug", m_bug);
			
			//̃oOXVĂꍇ
			} else {
				if (m_bug.isChanged()){
					//debug
					log.debug("is changed!");
					
					//oOCX^X̎擾
					m_bug = new Bug(m_form.getBno());
					//oOCX^X̃Zbg
					m_session.setAttribute("bug", m_bug);
				}
			}
			
			//͏Zbg
			PropertyUtils.copyProperties(m_form, m_bug);
			
			//show֑J
			forward = mapping.findForward("show");
			
		//XV̏ꍇ
		} else {
			
			//=========================
			//bugCX^X̎擾
			//=========================
			if ((m_bug == null) || (m_bug.getBno() != m_form.getBno())) {
				//xI
				log.warn("unmatch bno ");
				//oOCX^X̎擾
				m_bug = new Bug(m_form.getBno());
				//oOCX^X̍ăZbg
				m_session.setAttribute("bug", m_bug);
			}
			
			//`FbN
			ActionErrors errors = m_form.validate(mapping, request);
			if (!errors.empty()) {
				 saveErrors(request, errors);
				return (new ActionForward(mapping.getInput()));
			}
			
			try {
			
				//擾Jn
				m_bug.startActivity();
				
				//͏Zbg
				PropertyUtils.copyProperties(m_bug, m_form);
				//͏^CṽZbg
				m_bug.setInputType(Bug.ITYPE_DETAIL4);	
				
				//Xe[^X̍XV
				updateStatus();
				//r`FbN˂Ă܂XVB
				m_bug.update(m_logonUser.getUno());		//XV
				
				//͓e̒ǉ
				m_bug.addText(m_form.getAddText(), m_logonUser);
				//̎擾I
				m_bug.endActivity();
				
				//Ă
				Activitys act = m_bug.getActivitys();
				//[MsvłȂ
				if (! m_form.getDontSendMail()) {
					//[M
					act.sendMail(m_logonUser, request);
				}
				//̏o
				act.addActivity(m_logonUser);
				
				//OUPDATEĂ邽߂ɍXVeςȂꍇA
				//setPersistDateł̃j[NArG[ƂȂ
				//̂JDBChCoςĎ邪AƂ肠r`FbN
				//͂čXVB
				
				m_bug.update(m_logonUser.getUno(), false);		//rȂ̍XV
				
				//success֑J
				forward = mapping.findForward("success");
				
			//rO
			} catch (ExclusionException ee) {
				//debug
				log.debug("ExclusionException", ee);
				
				Varidater.addErrors("exp.exclusion", "bug", errors);
				saveErrors(request, errors);
				return (new ActionForward(mapping.getInput()));
				
			}
		}
		// Forward control to the specified success URI
		return forward;
	}
	/**
	 * Xe[^X̕ύX
	 */
	private void updateStatus() {
		
		String submitType = m_form.getSubmitType();
		//log
		log.debug("submiteType = " + submitType);
		log.debug("updater = " + m_form.getRequestUpdater() +
				  " analyst = " + m_form.getRequestAnalyst()
		);
		
		//s҂ɊmF˗
		if (submitType.equals("resolvedIssuer")) {
			m_bug.setUpdater(m_logonUser.getUno());	//CҐݒ
			m_bug.setBugUpdateDate(new Date());		//Cݒ
			m_bug.setComfirmer(m_bug.getIssuer());
			
			m_bug.setStatus(Bug.STS_RESOLVED);
			
		//mF
		} else if (submitType.equals("resolved")) {
			int resolver = Integer.parseInt(m_form.getRequestResolver());
			m_bug.setComfirmer(resolver);			//mFҐݒ
			m_bug.setBugUpdateDate(new Date());		//Cݒ
			
			m_bug.setStatus(Bug.STS_RESOLVED);
			
		//C
		} else if (submitType.equals("repaired")) {
			int updater = Integer.parseInt(m_form.getRequestUpdater());
			m_bug.setUpdater(updater);				//CҐݒ
			m_bug.setBugUpdateDate(new Date());		//Cݒ
			
			m_bug.setStatus(Bug.STS_REPAIRED);
			
		//͒
		} else if (submitType.equals("investigation")) {
			int analyst = Integer.parseInt(m_form.getRequestAnalyst());
			m_bug.setUpdater(m_logonUser.getUno());	//CҐݒ
			m_bug.setBugUpdateDate(new Date());		//Cݒ
			m_bug.setAnalyst(analyst);				//͎Ґݒ
			
			m_bug.setStatus(Bug.STS_INVESTIGATION);
			
		//̂܂
		} else if (submitType.equals("same")) {
			//ȂɂȂ
			
		//Xe[^X󋵕ύX
		} else if (submitType.equals("statusWhitebord")) {
			
			m_bug.setStatusWhitebord(m_form.getRequestStatusWhitebord());
			
		} else {
			//ɂ͗Ȃ͂
			Assert.check(false, "invalid submitType type = " + submitType);
			
		}
	}
}
